==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternate.md <==
# AmazonRdsProxyInstanceAlternate


```text
aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternate
```

```text
include('aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternate')
```



| Illustration | AmazonRdsProxyInstanceAlternate | AmazonRdsProxyInstanceAlternateCard | AmazonRdsProxyInstanceAlternateGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternate.png) | ![illustration for AmazonRdsProxyInstanceAlternate](../../../aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternate.Local.png) | ![illustration for AmazonRdsProxyInstanceAlternateCard](../../../aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternateCard.Local.png) | ![illustration for AmazonRdsProxyInstanceAlternateGroup](../../../aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternateGroup.Local.png) |




## AmazonRdsProxyInstanceAlternate

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonRdsProxyInstanceAlternate
include('aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternate')

' renders the element
AmazonRdsProxyInstanceAlternate('AmazonRdsProxyInstanceAlternate', 'Amazon Rds Proxy Instance Alternate', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonRdsProxyInstanceAlternate
include('aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternate')

' renders the element
AmazonRdsProxyInstanceAlternate('AmazonRdsProxyInstanceAlternate', 'Amazon Rds Proxy Instance Alternate', 'an optional tech label')
@enduml
```

## AmazonRdsProxyInstanceAlternateCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonRdsProxyInstanceAlternateCard
include('aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternate')

' renders the element
AmazonRdsProxyInstanceAlternateCard('AmazonRdsProxyInstanceAlternateCard', 'Amazon Rds Proxy Instance Alternate Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonRdsProxyInstanceAlternateCard
include('aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternate')

' renders the element
AmazonRdsProxyInstanceAlternateCard('AmazonRdsProxyInstanceAlternateCard', 'Amazon Rds Proxy Instance Alternate Card', 'an optional description')
@enduml
```

## AmazonRdsProxyInstanceAlternateGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonRdsProxyInstanceAlternateGroup
include('aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternate')

' renders the element
AmazonRdsProxyInstanceAlternateGroup('AmazonRdsProxyInstanceAlternateGroup', 'Amazon Rds Proxy Instance Alternate Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonRdsProxyInstanceAlternateGroup
include('aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternate')

' renders the element
AmazonRdsProxyInstanceAlternateGroup('AmazonRdsProxyInstanceAlternateGroup', 'Amazon Rds Proxy Instance Alternate Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternate.md <==
# AmazonRdsProxyInstanceAlternate


```text
aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternate
```

```text
include('aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternate')
```



| Illustration | AmazonRdsProxyInstanceAlternate | AmazonRdsProxyInstanceAlternateCard | AmazonRdsProxyInstanceAlternateGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternate.png) | ![illustration for AmazonRdsProxyInstanceAlternate](../../../aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternate.Local.png) | ![illustration for AmazonRdsProxyInstanceAlternateCard](../../../aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternateCard.Local.png) | ![illustration for AmazonRdsProxyInstanceAlternateGroup](../../../aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternateGroup.Local.png) |




## AmazonRdsProxyInstanceAlternate

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonRdsProxyInstanceAlternate
include('aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternate')

' renders the element
AmazonRdsProxyInstanceAlternate('AmazonRdsProxyInstanceAlternate', 'Amazon Rds Proxy Instance Alternate', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonRdsProxyInstanceAlternate
include('aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternate')

' renders the element
AmazonRdsProxyInstanceAlternate('AmazonRdsProxyInstanceAlternate', 'Amazon Rds Proxy Instance Alternate', 'an optional tech label')
@enduml
```

## AmazonRdsProxyInstanceAlternateCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonRdsProxyInstanceAlternateCard
include('aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternate')

' renders the element
AmazonRdsProxyInstanceAlternateCard('AmazonRdsProxyInstanceAlternateCard', 'Amazon Rds Proxy Instance Alternate Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonRdsProxyInstanceAlternateCard
include('aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternate')

' renders the element
AmazonRdsProxyInstanceAlternateCard('AmazonRdsProxyInstanceAlternateCard', 'Amazon Rds Proxy Instance Alternate Card', 'an optional description')
@enduml
```

## AmazonRdsProxyInstanceAlternateGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonRdsProxyInstanceAlternateGroup
include('aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternate')

' renders the element
AmazonRdsProxyInstanceAlternateGroup('AmazonRdsProxyInstanceAlternateGroup', 'Amazon Rds Proxy Instance Alternate Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonRdsProxyInstanceAlternateGroup
include('aws-q3-2021/Resource/Database/AmazonRdsProxyInstanceAlternate')

' renders the element
AmazonRdsProxyInstanceAlternateGroup('AmazonRdsProxyInstanceAlternateGroup', 'Amazon Rds Proxy Instance Alternate Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
